<script setup lang="ts">
import { computed, ref } from 'vue';

import { useVbenDrawer, useVbenModal } from '@vben/common-ui';
import { cloneDeep } from '@vben/utils';

import { InputSearch } from 'ant-design-vue';

import { useVbenForm } from '#/adapter/form';
import { addInspRecord, getInspRecord, updateInspRecord } from '#/api/eims/insp-record';
import CodeInput from '#/views/eims/components/code-input.vue';
import equModal from '#/views/eims/components/equ-modal.vue';
import userModal from '#/views/eims/components/user-modal.vue';

import { drawerSchema } from './data';


const emit = defineEmits<{ reload: [] }>();

const isUpdate = ref(false);
const title = computed(() => {
  return isUpdate.value ? '编辑点检记录' : '新增点检记录';
});

const [BasicForm, formApi] = useVbenForm({
  commonConfig: {
    formItemClass: 'col-span-2',
    componentProps: {
      class: 'w-full'
    },
    labelWidth: 120
  },
  schema: drawerSchema(),
  showDefaultActions: false,
  wrapperClass: 'grid-cols-2'
});

const [BasicDrawer, drawerApi] = useVbenDrawer({
  onCancel: handleCancel,
  onConfirm: handleConfirm,
  async onOpenChange(isOpen) {
    if (!isOpen) {
      return null;
    }
    drawerApi.drawerLoading(true);
    const { id } = drawerApi.getData() as { id?: number | string };
    isUpdate.value = !!id;
    // 从点检计划页面生成点检记录
    const { planInsp } = drawerApi.getData();
    isUpdate.value = !!id;
    // 新增-从点检计划页面生成点检记录
    if (!isUpdate.value && !id) {
      await formApi.setValues(planInsp);
    }
    formApi.updateSchema([
      {
        componentProps: {
          disabled: isUpdate.value
        },
        fieldName: 'inspName'
      }
    ]);
    // 更新 && 赋值
    if (isUpdate.value && id) {
      const record = await getInspRecord(id);
      await formApi.setValues(record);
    }

    drawerApi.drawerLoading(false);
  }
});


async function handleConfirm() {
  try {
    drawerApi.drawerLoading(true);
    const { valid } = await formApi.validate();
    if (!valid) {
      return;
    }
    const data = cloneDeep(await formApi.getValues());
    await (isUpdate.value ? updateInspRecord(data) : addInspRecord(data));
    emit('reload');
    await handleCancel();
  } catch (error) {
    console.error(error);
  } finally {
    drawerApi.drawerLoading(false);
  }
}



async function handleCancel() {
  drawerApi.close();
  await formApi.resetForm();
}

// equ modal
const [EquModal, equModalApi] = useVbenModal({
  connectedComponent: equModal,
  draggable: true,
  title: '选择设备'
});

function handleEquModal() {
  equModalApi.setData({});
  equModalApi.open();
}

// user modal
const [UserModal, userModalApi] = useVbenModal({
  connectedComponent: userModal,
  draggable: true,
  title: '选择点检人'
});

const userType = ref<number | undefined>(undefined);

function handleUserModal(type: number) {
  userType.value = type;
  userModalApi.setData({});
  userModalApi.open();
}

/**
 * 更新选择的设备
 * @param equ
 */
async function updateEqu(equ: any) {
  await formApi.setValues({equId:equ.equId,equName:equ.equName});
}

/**
 * 更新选择的用户
 * @param user
 */
async function updateUser(user: any) {
  if (userType.value === 1) {
    await formApi.setValues({ 'inspUserName': user.nickName, 'inspUser': user.userId, 'inspDept': user.deptId });
  } else if (userType.value === 2) {
    await formApi.setValues({ 'verifyUserName': user.nickName, 'verifyUser': user.userId, 'verifyDept': user.deptId });
  }
}
</script>

<template>
  <BasicDrawer :close-on-click-modal="false" :title="title" class="w-[600px]">
    <BasicForm>
      <template #equName="slotProps">
        <InputSearch :enter-button="true" placeholder="请选择" @search="handleEquModal" v-bind="slotProps"
                     :disabled="isUpdate" />
      </template>
      <template #inspUserName="slotProps">
        <InputSearch :enter-button="true" placeholder="请选择" @search="handleUserModal(1)" v-bind="slotProps" />
      </template>
      <template #verifyUserName="slotProps">
        <InputSearch :enter-button="true" placeholder="请选择" @search="handleUserModal(2)" v-bind="slotProps" />
      </template>
      <template #inspCode="slotProps">
        <CodeInput v-bind="slotProps" :disabled="isUpdate" prefix="DJSD" />
      </template>
    </BasicForm>
    <EquModal class="w-[1200px]" @update-equ="updateEqu" />
    <UserModal class="w-[1200px]" @select-user="updateUser" />
  </BasicDrawer>
</template>
